
#ifndef ___wnck_marshal_MARSHAL_H__
#define ___wnck_marshal_MARSHAL_H__

#include	<glib-object.h>

G_BEGIN_DECLS

/* VOID:FLAGS,FLAGS (wnck-marshal.list:25) */
extern void _wnck_marshal_VOID__FLAGS_FLAGS (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
                                             const GValue *param_values,
                                             gpointer      invocation_hint,
                                             gpointer      marshal_data);

G_END_DECLS

#endif /* ___wnck_marshal_MARSHAL_H__ */

